@@ -3,10 +3,9 @@ package DBIx::Class::Schema::Loader::DBI::Sybase::Microsoft_SQL_Server;
 use strict;
 use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI::MSSQL';
-use Carp::Clan qw/^DBIx::Class/;
 use mro 'c3';
 
-our $VERSION = '0.07002';
+our $VERSION = '0.07053';
 
 =head1 NAME
 
@@ -27,9 +26,9 @@ L<DBIx::Class::Schema::Loader::DBI::Sybase::Common>,
 L<DBIx::Class::Schema::Loader::DBI>
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
